@@ -88,11 +88,22 @@ class RotatableOpenSlide(object):
     def __new__(cls, filename, rotate):
         if cls is RotatableOpenSlide:
             bname, ext = os.path.splitext(filename)
-            if ext.upper() == '.DCM': return type("RotatableOpenSlide", (RotatableOpenSlide, dicomimage.ReadableDicomDataset,openslide.ImageSlide), {})(filename, rotate)
+            if ext.upper() == '.DCM': 
+                slideobj = type("RotatableOpenSlide", (RotatableOpenSlide, dicomimage.ReadableDicomDataset,openslide.ImageSlide), {})(filename, rotate)
+                slideobj.isOpenSlide = False
+                return slideobj
             if (ext.upper() in ['.NII','.GZ']): 
-                return type("ReadableNIBDataset", (RotatableOpenSlide,nifty.ReadableNIBDataset, openslide.ImageSlide ), {})(filename, rotate)
-            if ext.upper() == '.MKT': return type("ReadableCellVizioMKTDataset", (RotatableOpenSlide, cellvizio.ReadableCellVizioMKTDataset, openslide.ImageSlide), {})(filename,rotate)
-            if ext.upper() == '.TIF': return type("RotatableOpenSlide", (RotatableOpenSlide, ImageSlide3D,openslide.ImageSlide), {})(filename, rotate)
+                slideobj = type("ReadableNIBDataset", (RotatableOpenSlide,nifty.ReadableNIBDataset, openslide.ImageSlide ), {})(filename, rotate)
+                slideobj.isOpenSlide = False
+                return slideobj
+            if ext.upper() == '.MKT': 
+                slideobj = type("ReadableCellVizioMKTDataset", (RotatableOpenSlide, cellvizio.ReadableCellVizioMKTDataset, openslide.ImageSlide), {})(filename,rotate)
+                slideobj.isOpenSlide = False
+                return slideobj
+            if ext.upper() == '.TIF': 
+                slideobj = type("RotatableOpenSlide", (RotatableOpenSlide, ImageSlide3D,openslide.ImageSlide), {})(filename, rotate)
+                slideobj.isOpenSlide = False
+                return slideobj
             try:
                 slideobj = type("OpenSlide", (RotatableOpenSlide,openslide.OpenSlide), {})(filename, rotate)
                 slideobj.isOpenSlide = True
@@ -115,7 +126,6 @@ class RotatableOpenSlide(object):
 
 
 
-
     # Implements 180 degree rotated version of read_region
     def read_region(self, location, level, size, zLevel=0):
         # zlevel is ignored for SVS files
@@ -140,6 +150,15 @@ class RotatableOpenSlide(object):
         else:
             return location
 
+    def get_label_image(self, target_size_x):
+        if (self.isOpenSlide):
+            if 'label' in super().associated_images:
+                img = super().associated_images['label']
+                img = img.resize((target_size_x, int(img.size[1]/img.size[0]*target_size_x)))
+                return np.array(img)
+        
+        return None
+
     def slide_center(self):
         return [int(x/2) for x in self.dimensions]
     
